@@ -1,5 +1,7 @@
 from __future__ import annotations
 
+import os
+import sys
 from dataclasses import dataclass
 
 import click
@@ -14,7 +16,12 @@ from libcst.codemod import (
 )
 from libcst.metadata import PositionProvider
 
-__version__ = "0.2.1"
+__version__ = "0.3.1"
+
+# TODO(dhruvmanila): Remove this block when it's the default.
+# https://github.com/Instagram/LibCST/issues/285#issuecomment-1011427731
+if sys.version_info >= (3, 10):
+    os.environ["LIBCST_PARSER_TYPE"] = "native"
 
 
 @dataclass(frozen=False)
@@ -162,7 +169,7 @@ def check_file(
     try:
         with open(filename) as f:
             code = f.read()
-    except Exception as exc:
+    except Exception as exc:  # pragma: no cover
         click.secho(f"Could not read file {filename!r}, skipping: {exc}", fg="red")
         report.failure_count += 1
         return
@@ -181,9 +188,12 @@ def check_file(
                 with open(filename, "w") as f:
                     f.write(result.code)
     elif isinstance(result, TransformFailure):
-        click.secho(
-            f"Failed to transform the file {filename!r}: {result.error}", fg="red"
-        )
+        click.secho(f"Failed to transform the file {filename!r}: ", nl=False, fg="red")
+        try:
+            # FIXME: https://github.com/Instagram/LibCST/issues/678
+            click.secho(result.error, fg="red")
+        except Exception:
+            pass
         report.failure_count += 1
 
 
